<?php

/*
  作成者: ihara789
  作成日: 2023/02/01
  更新日: 2023/02/15
  パスワードのハッシュを生成し、新規コンテンツの追加方法を表示する。
*/

class PasswordHasher
{
    private $id;
    private $password;
    private $hashed_password = '';
    private $message = '';

    function __construct($id, $password)
    {
        $this->id = $id;
        $this->password = $password;
    }

    function hash_password()
    {
        $this->hashed_password = password_hash($this->password, PASSWORD_DEFAULT);
        return $this->hashed_password;
    }

    function get_message()
    {
        return $this->message;
    }

    function process($ids)
    {
        if (empty($this->id)) {
            $this->message = 'IDが入力されていません。';
            return false;
        } elseif (empty($this->password)) {
            $this->message = 'パスワードが入力されていません。';
            return false;
        } elseif (in_array($this->id, $ids)) {
            $this->message = 'IDが重複しています。';
            return false;
        } else {
            $this->hash_password();
            $this->message = '利用可能なID・パスワードの組み合わせです。';
            return true;
        }
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $id = $_POST['id'];
    $password = $_POST['password'];
    $data = include('account_list.php');
    $ids = array_column($data, 'id');

    $hasher = new PasswordHasher($id, $password);
    $show_main_content = $hasher->process($ids);
    $message = $hasher->get_message();
    $hashed_password = $hasher->hash_password();
} else {
    header('Location: index.php');
    exit;
}

// 現在のページのURL
$current_url = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";

// 一つ上の階層のURL
$parent_url = dirname($current_url);

// 二つ上の階層のURL
$grandparent_url = dirname($parent_url);
?>

<!DOCTYPE html>
<html>
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
  <meta name="viewport" content="width=device-width">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <title>Page Access Control Tool</title>
  <meta name="robots" content="noindex">
  <link rel="stylesheet" href="css/style.css" />
  <script src="js/hash_password.js"></script>

  <link rel="icon" href="https://cf035666.cloudfree.jp/assets/img/favicon.ico">
  <meta property="og:title" content="Page Access Control Tool | My First Challenge in JavaScript (and PHP)">
  <meta property="og:description" content="ページ閲覧制限ツール">
  <meta property="og:url" content="https://cf035666.cloudfree.jp/05-pac/">
  <meta property="og:image" content="https://cf035666.cloudfree.jp/assets/img/ogp.png">
  <meta property="og:type" content="website">
  <meta property="og:site_name" content="My First Challenge in JavaScript (and PHP)">
  <meta name="twitter:card" content="summary_large_image">
  <!--
  <meta name="robots" content="noindex">
  -->

  <?php echo "<script>var userId = " . json_encode($id) . ";</script>"; ?>
</head>
<body>

<div class="container hs">
<header class="header">
    <h1 class="header__ttl"><a href="./">Page Access Control Tool</a></h1>
    <h2 class="header__subttl"><a href="./">ページ閲覧制限ツール</a></h2>
    <p class="header__link"><a href="../">Home</a></p>
</header>

<main class="main">
<section class="hash__sec">
<?php if ($show_main_content): ?>
        <h2 class="hash__sec__ttl">新規登録（管理者用）</h2>
        <p class="hash__msg"><?php echo $message; ?></p>

        <div class="hash__dlwrap">
        <h3 class="hash__dl__ttl">設定方法の保存</h3>
        <p class="hash__dltxt">設定方法はテキスト形式でダウンロードできます。</p>
        <button class="hash__btn" id="setting_Button">クリックして保存</button>
    </div>

        <div id="setting_txt">
        <h3>設定方法</h3>
        <br>
        <h4>1 ）ツールの準備 　　　------------------------------------</h4>
        <br>
        <p><a href="<?php echo $grandparent_url; ?>/dl/05-pac.zip">コード一式をダウンロード</a>して解凍し、サーバーへアップロードしてください。</p>
        <p>　・[ <a href="<?php echo $grandparent_url; ?>/dl/dl/05-pac.zip"><?php echo $grandparent_url; ?>/dl/05-pac.zip</a> ]</p>
        <br>
        <h4>2 ）アカウントの登録 　------------------------------------</h4>
        <br>
        <p>[ account_list.php ] をテキストエディタで開き、次の内容を追加してアップロードしてください。</p>
        <pre><code>
        [
            'id' => '<?php echo $id; ?>',
            'pass' => '<?php echo $hashed_password; ?>',
        ],
        </code></pre>
        <br>
        <h4>3 ）ページの準備 　　　------------------------------------</h4>
        <br>
        <p>[ data ] フォルダ内の [ sample.php ] を、同じフォルダ内にコピーします。</p>
        <p>コピーしたファイル名を、[ <?php echo $id; ?>.php ] に変更します。</p>
        <br>
        <p>※ [ data ] フォルダ内の [ index.php・index.html ] は削除しないでください。</p>
        <br>
        <h4>4 ）ページの編集 　　　------------------------------------</h4>
        <br>
        <p>[ <?php echo $id; ?>.php ] をテキストエディタで開き、公開内容を記述します。</p>
        <p>保存後、[ data ] フォルダにアップロードします。</p>
        <br>
        <p>※ &lt;!-- ↓ 編集エリア ↓ --&gt; ～ &lt;!-- ↑ 編集エリア ↑ --&gt;の内容を編集してください。</p>
        <p>※ 公開終了日を指定する場合は6行名の [ $end_date = ""; ] を編集します。<br>
        　 詳細は5行目のコメント部分を確認してください。</p>
        <br>
        <h4>5 ）表示確認 　　　　　------------------------------------</h4>
        <br>
        <p>5-1）<a href="<?php echo $parent_url; ?>/data/<?php echo $id; ?>.php">アップロードしたページ</a>が、
        ログインしていない状態で非表示であることを確認します。</p>
        <p>　・[ <a href="<?php echo $parent_url; ?>/data/<?php echo $id; ?>.php"><?php echo $parent_url; ?>/data/<?php echo $id; ?>.php</a> ]</p>
        <br>
        <p>5-2）<a href="<?php echo $parent_url; ?>/index.php?tab=login">ログインページ</a>に戻り、
        idとpassを入力して表示を確認します。</p>
        <p>　・[ <a href="<?php echo $parent_url; ?>/index.php?tab=login"><?php echo $parent_url; ?>/index.php?tab=login</a> ]</p>
        <br>
        <p>※設定アカウントでログイン済の場合は、ブラウザを一度閉じるか、シークレットモードで確認します。</p>
        <p>※正しく表示されない場合は、以下を確認します。<br>
        ・サーバーの [ account_list.php ] に、新規ID・passの追加が反映されているか。<br>
        ・[ <?php echo $id; ?>.php ] が、サーバーの [ data ] フォルダにアップロードされているか。<br>
        ・ファイル名が [ <?php echo $id; ?>.php ] となっているか。</p>
        <br>
        <h4>6 ）アカウントの提供 　------------------------------------</h4>
        <br>
        <h5></h5>
        <p>情報を公開する相手に、下記の内容を伝えてください。</p>
        <div class="login_acc"><p>
        ▽ ログインURL: <?php echo $parent_url; ?><br>
        ▽ id: <?php echo $id; ?><br>
        ▽ pass: <?php echo $password; ?>
        </p></div>
        <br>
        <br>
        </div>
        <hr>
        <p><a href="<?php echo $parent_url; ?>/index.php?tab=login">ログインページへ戻る</a></p>
    <?php else: ?>
            <h2 class="hash__sec__ttl">新規登録（管理者用）</h2>
            <p class="hash__msg"><?php echo $message; ?></p>
            <p class="hash__ng-txt">[ <a href="<?php echo $parent_url; ?>/index.php?tab=convert">新規登録（管理者用）</a>]に戻り、もう一度入力してください。</p>
    <?php endif; ?>
    </section>
</main>
<footer class="footer">
    <h2 class="footer__ttl"><a href="./">Page Access Control Tool</a></h2>
    <p class="footer__link"><a href="../">Home</a></p>
</footer>
</div>
  <!-- Google tag (gtag.js) -->
  <script async src="https://www.googletagmanager.com/gtag/js?id=G-1YPNE8S4M5"></script>
  <script>
    window.dataLayer = window.dataLayer || [];
    function gtag() { dataLayer.push(arguments); }
    gtag('js', new Date());

    gtag('config', 'G-1YPNE8S4M5');
  </script>
</body>
</html>