<?php

/*
  作成者: ihara789
  作成日: 2023/02/01
  更新日: 2023/02/15
  ログイン処理を実施し、IDとPassが正しい場合に対応するファイルを表示する。
*/

class Login
{
    private $max_attempts = 5;
    private $message = '';
    private $id;
    private $pass;

    function __construct($id, $pass)
    {
        session_start();
        $this->id = htmlspecialchars($id, ENT_QUOTES, 'UTF-8');
        $this->pass = $pass;

        if (!isset($_SESSION['login_attempts'])) {
            $_SESSION['login_attempts'] = 0;
            $_SESSION['first_attempt_time'] = time();
        }
    }

    function attempt_login()
    {
        if (time() - $_SESSION['first_attempt_time'] > 1 * 60) {
            $_SESSION['login_attempts'] = 0;
            $_SESSION['first_attempt_time'] = time();
        }

        if ($_SESSION['login_attempts'] >= $this->max_attempts) {
            $this->message = 'ログイン試行回数が上限に達しました。1分後に再度お試しください。';
        } else {
            $data = include 'account_list.php';

            $flag = false;
            foreach ($data as $item) {
                if ($item['id'] === $this->id && password_verify($this->pass, $item['pass'])) {
                    $_SESSION['id'] = $this->id;
                    $flag = true;
                    break;
                }
            }

            if (!$flag) {
                $_SESSION['login_attempts']++;
                $this->message = 'IDまたはパスワードが正しくありません。';
            } else {
                if (isset($_SESSION['id'])) {
                    $filename = './data/' . $_SESSION['id'] . '.php';
                    if (file_exists($filename)) {
                        header('Location: ' . $filename);
                        exit;
                    } else {
                        $this->message = 'ファイルが存在しません。管理者に連絡してください。<br>';
                        // $this->message .= ' ファイルパス: ' . $filename;
                    }
                } else {
                    $_SESSION['login_attempts'] = 0;
                    $_SESSION['first_attempt_time'] = time();
                    header('Location: login.php');
                }
            }
        }
    }

    function get_message()
    {
        return $this->message;
    }
}

$login = new Login($_POST['id'], $_POST['pass']);
$login->attempt_login();
$message = $login->get_message();
?>

<!DOCTYPE html>
<html>
<head>
  <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
  <meta name="viewport" content="width=device-width">
  <meta http-equiv="X-UA-Compatible" content="IE=edge">
  <meta name="robots" content="noindex">
  <title>Page Access Control Tool</title>
  <link rel="stylesheet" href="css/style.css" />

  <link rel="icon" href="https://cf035666.cloudfree.jp/assets/img/favicon.ico">
  <meta property="og:title" content="Page Access Control Tool | My First Challenge in JavaScript (and PHP)">
  <meta property="og:description" content="ページ閲覧制限ツール">
  <meta property="og:url" content="https://cf035666.cloudfree.jp/05-pac/">
  <meta property="og:image" content="https://cf035666.cloudfree.jp/assets/img/ogp.png">
  <meta property="og:type" content="website">
  <meta property="og:site_name" content="My First Challenge in JavaScript (and PHP)">
  <meta name="twitter:card" content="summary_large_image">
  <!--
  <meta name="robots" content="noindex">
  -->

</head>
<body>
<div class="container">
<header class="header">
    <h1 class="header__ttl">Page Access Control Tool</h1>
    <h2 class="header__subttl">ページ閲覧制限ツール</h2>
    <p class="header__link"><a href="../">Home</a></p>
</header>

<main class="main">
    <section class="login__sec">
    <h3 class="login__ttl">ログインできませんでした。</h3>
    <p class="login__msg">
        <?php echo $message; ?>
    </p>
    <p class="login__btn"><a href="./index.php">戻る</a></p>
    </session>
</main>

<footer class="footer">
    <h2 class="footer__ttl">Page Access Control Tool</h2>
    <p class="footer__link"><a href="../">Home</a></p>
</footer>
</div>
  <!-- Google tag (gtag.js) -->
  <script async src="https://www.googletagmanager.com/gtag/js?id=G-1YPNE8S4M5"></script>
  <script>
    window.dataLayer = window.dataLayer || [];
    function gtag() { dataLayer.push(arguments); }
    gtag('js', new Date());

    gtag('config', 'G-1YPNE8S4M5');
  </script>
</body>
</html>